# roipy

Plotting brain regions of interest (ROI) for demonstration purposes in Python

## Description

Have you ever wanted to plot a region of the brain to include in a talk or presentation? What about in a lecture? Some might arbitrarily highlight the area of the cortex in which they _think_ a particular region might fall. Others might scour the internet for images. Well...you won't need to do that any more. With `roipy`, you can plot exact regions of the brain using the [**Destrieux Atlas**](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC2937159/).

## Usage

### Installation

